@@ -1134,6 +1134,9 @@ class SnowballEmmcConfig(SnowballSdConfig):
                   'r') as info_file:
             for line in info_file:
                 file_data = line.split()
+                if len(file_data) == 0:
+                    # Line contains only whitespace
+                    continue
                 if file_data[0][0] == '#':
                     continue
                 if file_data[1].startswith('/'):
@@ -1262,9 +1265,9 @@ class VexpressConfig(BoardConfig):
     serial_tty = 'ttyAMA0'
     _extra_serial_opts = 'console=tty0 console=%s,38400n8'
     _live_serial_opts = 'serialtty=%s'
-    kernel_addr = '0x60008000'
-    initrd_addr = '0x81000000'
-    load_addr = kernel_addr
+    kernel_addr = '0x60000000'
+    initrd_addr = '0x62000000'
+    load_addr = '0x60008000'
     kernel_flavors = ['linaro-vexpress']
     boot_script = 'boot.scr'
     # ARM Boot Monitor is used to load u-boot, uImage etc. into flash and
@@ -1448,6 +1451,7 @@ board_configs = {
     'overo': OveroConfig,
     'smdkv310': SMDKV310Config,
     'origen': OrigenConfig,
+    'mx6qsabrelite': BoardConfig,
     }
 
 
